unit FileIO;

interface

const CONTROL_VERSION_225 = 20;  { Version number for document files which have
                                   been created with the TX4VB 2.25 MDI demo}
      CONTROL_VERSION_230 = 23; { Version number for document files}

Type FILE_HEADER = record         // Structure for document file header
         lVersion : LongInt;
     End;

procedure FileSaveProc;
procedure FileSaveAsProc;
procedure SaveFile(Filename:string);
procedure OpenFile(Filename : String; FileType : Integer; FileIns : Boolean);
Function GetSaveFileName:string;


implementation

uses MDIFrame, MDIEdit, TXglobal, SysUtils, Dialogs;

{-------------------------------------------------------------------------
  FileSaveProc

  Save current text
 -------------------------------------------------------------------------}
procedure FileSaveProc;
var Filename : String;
begin
  with TEditForm(FrameForm.ActiveMDIChild) do begin
    If copy(Caption,1 , 8) = 'Untitled' Then begin
       {The file hasn't been saved yet,
        get the filename, then call the save procedure}
        Filename := GetSaveFileName;
     end
    Else begin
        // The caption contains the name of the open file
        Filename := Caption;
     end;

    {Call the save procedure, if Filename = Empty then
     the user selected Cancel in the Save As dialog, otherwise
     save the file}
    If Filename <> '' Then SaveFile(Filename);
   end;
End;


{-------------------------------------------------------------------------
  FileSaveAsProc

  Get new text filename and saves text
 -------------------------------------------------------------------------}
procedure FileSaveAsProc;
var Filename : String;
begin
  Filename := GetSaveFileName;
  If Filename <> '' Then SaveFile(Filename);
End;


{-------------------------------------------------------------------------
  SaveFile

  Save the contents of the active form in the file given in the
  "filename" parameter.

  Parameters: FileName: Name of the file to be loaded (string)
-------------------------------------------------------------------------}
procedure SaveFile(Filename:string);
var FileHeader  : FILE_HEADER;
    FileType    : Integer;
    lFilePos    : LongInt;
    outFile     : file of byte;
begin
  FrameForm.Cursor:= -11;   // Hourglass
  with TEditForm(FrameForm.ActiveMDIChild) do begin

    try
     // Determine file type from filename extension
     name := UpperCase(copy(Filename, length(FileName)-2, 3));
     If name = 'RTF' Then
        FileType := RTF_FILE
     else If name = 'TXT' Then
        FileType := TXT_FILE
     else If name = 'DOC' Then
          FileType := DOC_FILE
     Else FileType := TXM_FILE;

     Case Filetype of
          TXM_FILE: begin// Save RTF file
                  // Open the file
                  AssignFile(outFile,filename);
                  rewrite(outFile);
                  // Write file header
                  FileHeader.lVersion := CONTROL_VERSION_230;
                  BlockWrite(outFile,FileHeader,SizeOf(FileHeader));
                  // Write page size and margins
                  Doc.lLeftMargin := TX.PageMarginL;
                  Doc.lTopMargin := TX.PageMarginT;
                  Doc.lRightMargin := TX.PageMarginR;
                  Doc.lBottomMargin := TX.PageMarginB;
                  Doc.lWidth := TX.PageWidth;
                  Doc.lHeight := TX.PageHeight;
                  BlockWrite(outFile,Doc,sizeOf(Doc));
                  lFilePos := FilePos(outFile);
                  CloseFile(outFile);

                  // Write text control contents
                  TX.Save(Filename, lFilePos, TXM_FILE, false);
               end
          Else begin
               TX.LoadSaveAttribute[0] := TX.PageWidth ;
               TX.LoadSaveAttribute[1] := TX.PageHeight ;
               TX.LoadSaveAttribute[2] := TX.PageMarginL ;
               TX.LoadSaveAttribute[3] := TX.PageMarginT ;
               TX.LoadSaveAttribute[4] := TX.PageMarginR ;
               TX.LoadSaveAttribute[5] := TX.PageMarginB ;
               TX.Save(Filename, 0, FileType, false);
          end;
      end;  //Case

     // Set the window caption
     Caption := UpperCase(Filename);
     // reset the dirty flag
     Dirty := False;

    except
       MessageDlg('Error saving file '+filename,mtError,[mbOK],0);
       FrameForm.Cursor:=0;   // default
    end;

    FrameForm.Cursor:=0;   // default

  end; // with
end;

{-------------------------------------------------------------------------
  GetSaveFileName

  Get a new filename
  Displays a Save As dialog and returns a file name
  or an empty string if the user cancels
 -------------------------------------------------------------------------}
Function GetSaveFileName:string;
var Filename : String;
begin
  with TEditForm(FrameForm.ActiveMDIChild) do begin
     SaveFileDialog.Title := 'Save As';
     SaveFileDialog.Filter := 'Text Control Demo (*.txm)|*.txm|Rich Text Format (*.rtf)|*.rtf|Plain Text (*.txt)|*.txt|Word Document (*.doc)|*.doc';
     SaveFileDialog.DefaultExt := 'txm';
     SaveFileDialog.Filename := '';

     if SaveFileDialog.Execute then
        Filename := SaveFileDialog.Filename
     else Filename := ''; // user canceled dialog

     GetSaveFileName := Filename;
   end;
End;

{-------------------------------------------------------------------------
 OpenFile

 Open the file given in the "filename" parameter, create a new MDI
 child and text control and load the file contents.

 Parameters: FileName: Name of the file to be loaded (string)
             FileType: Type (TXM_FILE ot RTF_FILE)
-------------------------------------------------------------------------}
procedure OpenFile(Filename : String; FileType : Integer; FileIns : Boolean);
var FileHeader : FILE_HEADER;
    lFilePos   : LongInt;
    bOpen      : boolean;
    InpFile    : file of byte;
begin
  bOpen  := False;
  FrameForm.Cursor:= -11;    // Hourglass

  with TEditForm(FrameForm.ActiveMDIChild) do begin

    try
    Case FileType of
         TXM_FILE: begin
        // Open the selected file
        AssignFile(inpFile,filename);
        reset(inpFile);
        bOpen := True;
        // Read file header
        BlockRead(inpFile,FileHeader,sizeOf(FileHeader));

        {If this is a version 230 file, read page size and margins. Else
         use the defaults from version 2.25}
       If FileHeader.lVersion = CONTROL_VERSION_230 Then begin
           BlockRead(inpFile,Doc,sizeOf(Doc));
           TX.PageMarginL := Doc.lLeftMargin;
           TX.PageMarginT := Doc.lTopMargin;
           TX.PageMarginR := Doc.lRightMargin;
           TX.PageMarginB := Doc.lBottomMargin;
           TX.PageWidth := Doc.lWidth;
           TX.PageHeight := Doc.lHeight;
         end
        Else begin
           TX.PageMarginL := 1440;
           TX.PageMarginT := 1440;
           TX.PageMarginR := 1440;
           TX.PageMarginB := 1440;
           TX.PageWidth := DINA4_X;
           TX.PageHeight := DINA4_Y;
         End;
        lFilePos := filepos(inpFile);
        CloseFile(inpFile);
        bOpen:= False;
        TX.Load(Filename, lFilePos, TXM_FILE, FileIns);
      End
      else begin  // Load RTF file
            TX.Load(Filename, 0, FileType, false);
            If TX.LoadSaveAttribute[0] > 0 Then
               TX.PageWidth := TX.LoadSaveAttribute[0];
            If TX.LoadSaveAttribute[1] > 0 Then
               TX.PageHeight := TX.LoadSaveAttribute[1];
            If TX.LoadSaveAttribute[2] > 0 Then
               TX.PageMarginL := TX.LoadSaveAttribute[2];
            If TX.LoadSaveAttribute[3] > 0 Then
               TX.PageMarginT := TX.LoadSaveAttribute[3];
            If TX.LoadSaveAttribute[4] > 0 Then
               TX.PageMarginR := TX.LoadSaveAttribute[4];
            If TX.LoadSaveAttribute[5] > 0 Then
               TX.PageMarginB := TX.LoadSaveAttribute[5];
            TX.SelStart := 0;
            end;
      end; //case

     // Change form's caption and display new text
     Caption := UpperCase(Filename);
     Show;

    except
       MessageDlg('Error opening '+filename,mtError,[mbOK],0);
       if bOpen then begin
          closeFile(inpFile);
        end;
       FrameForm.Cursor:=0;   // default
       close;
    end;

   FrameForm.Cursor:=0;       //default

  end;
end;

end.