unit framedlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, MDIFrame, Tx4oleLib_TLB, MDIEdit, TXGLOBAL;

type
  TFramesDlg = class(TForm)
    GroupBox1: TGroupBox;
    chkLeft: TCheckBox;
    chkRight: TCheckBox;
    chkTop: TCheckBox;
    chkBottom: TCheckBox;
    chkTabLines: TCheckBox;
    GroupBox2: TGroupBox;
    chkConnected: TCheckBox;
    chkDoubleLines: TCheckBox;
    cmdOK: TButton;
    cmdCancel: TButton;
    Label1: TLabel;
    Label2: TLabel;
    cboLineWidth: TComboBox;
    cboTextDistance: TComboBox;
    procedure FormShow(Sender: TObject);
    procedure chkLeftClick(Sender: TObject);
    procedure chkRightClick(Sender: TObject);
    procedure chkTopClick(Sender: TObject);
    procedure chkBottomClick(Sender: TObject);
    procedure chkTabLinesClick(Sender: TObject);
    procedure chkConnectedClick(Sender: TObject);
    procedure chkDoubleLinesClick(Sender: TObject);
    procedure cmdOKClick(Sender: TObject);
    procedure cmdCancelClick(Sender: TObject);
  private
    glwCheckboxStateChanged : integer;
  public

  end;

var
  FramesDlg: TFramesDlg;

implementation

{$R *.DFM}

procedure TFramesDlg.FormShow(Sender: TObject);
Var wFrameLineWidth, wFrameDistance, wFrameStyle,
    n : Integer;
begin
   // Get active MDI form data
   with TEditForm(FrameForm.ActiveMDIChild).TX do begin
        // Copy property values to local variables
        wFrameLineWidth := FrameLineWidth;
        wFrameDistance := FrameDistance;
        wFrameStyle := FrameStyle;
    end;

   // Set state of checkboxes
   chkLeft.Checked := (BF_LEFTLINE = (wFrameStyle And BF_LEFTLINE));
   chkRight.Checked := (BF_RIGHTLINE = (wFrameStyle And BF_RIGHTLINE));
   chkTop.Checked := (BF_TOPLINE = (wFrameStyle And BF_TOPLINE));
   chkBottom.Checked := (BF_BOTTOMLINE = (wFrameStyle And BF_BOTTOMLINE));
   chkTablines.Checked := (BF_TABLINES = (wFrameStyle And BF_TABLINES));
   chkConnected.Checked := (BF_BOXCONNECT = (wFrameStyle And BF_BOXCONNECT));
   chkDoubleLines.Checked := (BF_DOUBLE = (wFrameStyle And BF_DOUBLE));
   glwCheckboxStateChanged := 0;

   // Initialize combo boxes.
   For n := 1 To 12 do cboLineWidth.Items.Add(IntToStr(n) + ' pt');
   If wFrameLineWidth <> -1 Then cboLineWidth.Text := IntToStr(trunc(wFrameLineWidth / 20)) + ' pt';

   For n := 0 To 12 do cboTextDistance.Items.Add(IntToStr(n) + ' pt');
   If wFrameDistance <> -1 Then cboTextDistance.Text := IntToStr(trunc(wFrameDistance / 20)) + ' pt';

end;

procedure TFramesDlg.chkLeftClick(Sender: TObject);
begin
  glwCheckboxStateChanged := glwCheckboxStateChanged Or BF_LEFTLINE;
end;

procedure TFramesDlg.chkRightClick(Sender: TObject);
begin
  glwCheckboxStateChanged := glwCheckboxStateChanged Or BF_RIGHTLINE;
end;

procedure TFramesDlg.chkTopClick(Sender: TObject);
begin
  glwCheckboxStateChanged := glwCheckboxStateChanged Or BF_TOPLINE;
end;

procedure TFramesDlg.chkBottomClick(Sender: TObject);
begin
  glwCheckboxStateChanged := glwCheckboxStateChanged Or BF_BOTTOMLINE;
end;

procedure TFramesDlg.chkTabLinesClick(Sender: TObject);
begin
  glwCheckboxStateChanged := glwCheckboxStateChanged Or BF_TABLINES;
end;

procedure TFramesDlg.chkConnectedClick(Sender: TObject);
begin
  glwCheckboxStateChanged := glwCheckboxStateChanged Or BF_BOXCONNECT;
end;

procedure TFramesDlg.chkDoubleLinesClick(Sender: TObject);
begin
  glwCheckboxStateChanged := glwCheckboxStateChanged Or BF_DOUBLE;
end;

procedure TFramesDlg.cmdOKClick(Sender: TObject);
Var wNewFrameStyle,
    n,
    code : Integer;
begin
  { Get checkbox settings.
    The state of a checkbox is taken into account only if it
    has been changed by the user. This way, multiple selected
    paragraphs with different settings can be processed.}
  wNewFrameStyle := 0;
  If (BF_LEFTLINE = (glwCheckboxStateChanged and BF_LEFTLINE)) Then begin
      If chkLeft.checked Then
           wNewFrameStyle := wNewFrameStyle Or BF_LEFTLINE
      Else wNewFrameStyle := wNewFrameStyle Or BF_NOLEFTLINE;
   End;

  If (BF_RIGHTLINE = (glwCheckboxStateChanged and BF_RIGHTLINE)) Then begin
      If chkRight.checked Then
          wNewFrameStyle := wNewFrameStyle Or BF_RIGHTLINE
      Else wNewFrameStyle := wNewFrameStyle Or BF_NORIGHTLINE;
   End;

  If (BF_TOPLINE = (glwCheckboxStateChanged and BF_TOPLINE)) Then begin
      If chkTop.checked Then
          wNewFrameStyle := wNewFrameStyle Or BF_TOPLINE
      Else wNewFrameStyle := wNewFrameStyle Or BF_NOTOPLINE;
   End;

  If (BF_BOTTOMLINE = (glwCheckboxStateChanged and BF_BOTTOMLINE)) Then begin
      If chkBottom.checked Then
          wNewFrameStyle := wNewFrameStyle Or BF_BOTTOMLINE
      Else wNewFrameStyle := wNewFrameStyle Or BF_NOBOTTOMLINE;
   End;

  If (BF_TABLINES = (glwCheckboxStateChanged and BF_TABLINES)) Then begin
      If chkTablines.checked Then
          wNewFrameStyle := wNewFrameStyle Or BF_TABLINES
      Else wNewFrameStyle := wNewFrameStyle Or BF_NOTABLINES;
   End;

  If (BF_BOXCONNECT = (glwCheckboxStateChanged and BF_BOXCONNECT)) Then begin
      If chkConnected.checked Then
          wNewFrameStyle := wNewFrameStyle Or BF_BOXCONNECT;
   End;

  If (BF_DOUBLE = (glwCheckboxStateChanged and BF_DOUBLE)) Then begin
      If chkDoubleLines.checked Then
          wNewFrameStyle := wNewFrameStyle Or BF_DOUBLE
      Else wNewFrameStyle := wNewFrameStyle Or BF_SINGLE;
   End;

  TEditForm(FrameForm.ActiveMDIChild).TX.FrameStyle:=wNewFrameStyle;

  // Copy combobox settings, convert values to point
  If cboLineWidth.Text <> '' Then begin
      Val(cboLineWidth.Text, n, Code);
      If (n < 1) Then n := 1;
      If (n > 12) Then n := 12;
      TEditForm(FrameForm.ActiveMDIChild).TX.FrameLineWidth := n * 20;
   End;

  If cboTextDistance.Text <> '' Then begin
      Val(cboTextDistance.Text, n, Code);
      If (n < 0) Then n := 0;
      If (n > 12) Then n := 12;
      TEditForm(FrameForm.ActiveMDIChild).TX.FrameDistance := n * 20;
   End;

  // Quit dialog box
  Close;

end;

procedure TFramesDlg.cmdCancelClick(Sender: TObject);
begin
  close;
end;

end.
